
# mpl-draggable-line's Documentation

Draggable Line Widget for matplotlib


## Basic Usage

```python
# a basic usage example can go here
print(1+1)
```

## Install
```bash
pip install mpl-draggable-line
```



```{toctree}
:maxdepth: 2

API <api/mpl_draggable_line>
contributing
```

```{toctree}
:caption: Examples
:maxdepth: 1

examples/basic-example.ipynb
```
